@@ -41,11 +41,11 @@ module ApplicationTests
     def assert_file_exists(filename)
       globbed = Dir[filename]
       assert Dir.exist?(File.dirname(filename)), "Directory #{File.dirname(filename)} does not exist"
-      assert globbed.one?, "Found #{globbed.size} files matching #{filename}. All files in the directory: #{Dir.entries(File.dirname(filename)).inspect}"
+      assert_predicate globbed, :one?, "Found #{globbed.size} files matching #{filename}. All files in the directory: #{Dir.entries(File.dirname(filename)).inspect}"
     end
 
     def assert_no_file_exists(filename)
-      assert !File.exist?(filename), "#{filename} does exist"
+      assert_not File.exist?(filename), "#{filename} does exist"
     end
 
     test "assets routes have higher priority" do
@@ -66,20 +66,6 @@ module ApplicationTests
       assert_equal 'a = "/assets/rails.png";', last_response.body.strip
     end
 
-    test "assets do not require compressors until it is used" do
-      app_file "app/assets/javascripts/demo.js.erb", "<%= :alert %>();"
-      add_to_env_config "production", "config.assets.compile = true"
-      add_to_env_config "production", "config.assets.precompile = []"
-
-      # Load app env
-      app "production"
-
-      assert !defined?(Uglifier)
-      get "/assets/demo.js"
-      assert_match "alert()", last_response.body
-      assert defined?(Uglifier)
-    end
-
     test "precompile creates the file, gives it the original asset's content and run in production as default" do
       app_file "app/assets/config/manifest.js", "//= link_tree ../javascripts"
       app_file "app/assets/javascripts/application.js", "alert();"
@@ -131,7 +117,7 @@ module ApplicationTests
       app_file "app/assets/javascripts/something.else.js.erb", "alert();"
       app_file "app/assets/stylesheets/something.else.css.erb", "body{}"
 
-      app_file "app/assets/config/manifest.js", <<-JS.strip_heredoc
+      app_file "app/assets/config/manifest.js", <<~JS
         //= link_tree ../images
         //= link_directory ../stylesheets .css
         //= link_directory ../javascripts .js
@@ -176,11 +162,7 @@ module ApplicationTests
 
       precompile!
 
-      if sprockets_4?
-        assert_file_exists("#{app_path}/public/assets/something-*.js")
-      else
-        assert_file_exists("#{app_path}/public/assets/something/index-*.js")
-      end
+      assert_file_exists("#{app_path}/public/assets/something-*.js")
     end
 
     test "precompile use assets defined in app env config" do
@@ -255,28 +237,19 @@ module ApplicationTests
     end
 
     test "the manifest file should be saved by default in the same assets folder" do
-      if sprockets_4?
-        app_file "app/assets/stylesheets/test.css", "a{color: red}"
-      else
-        app_file "app/assets/javascripts/application.js", "alert();"
-      end
+      app_file "app/assets/stylesheets/test.css", "a{color: red}"
       add_to_config "config.assets.prefix = '/x'"
 
       precompile!
 
       manifest = Dir["#{app_path}/public/x/.sprockets-manifest-*.json"].first
       assets = ActiveSupport::JSON.decode(File.read(manifest))
-      if sprockets_4?
-        assert_match(/test-([0-z]+)\.css/, assets["assets"]["test.css"])
-      else
-        assert_match(/application-([0-z]+)\.js/, assets["assets"]["application.js"])
-      end
+      assert_match(/test-([0-z]+)\.css/, assets["assets"]["test.css"])
     end
 
     test "assets do not require any assets group gem when manifest file is present" do
       app_file "app/assets/javascripts/application.js", "alert();"
       app_file "app/assets/config/manifest.js", "//= link application.js"
-      add_to_env_config "production", "config.public_file_server.enabled = true"
 
       precompile! RAILS_ENV: "production"
 
@@ -288,10 +261,10 @@ module ApplicationTests
       app "production"
 
       # Checking if Uglifier is defined we can know if Sprockets was reached or not
-      assert !defined?(Uglifier)
-      get "/assets/#{asset_path}"
+      assert_not defined?(Uglifier)
+      get("/assets/#{asset_path}", {}, "HTTPS" => "on")
       assert_match "alert()", last_response.body
-      assert !defined?(Uglifier)
+      assert_not defined?(Uglifier)
     end
 
     test "precompile properly refers files referenced with asset_path" do
@@ -346,12 +319,12 @@ module ApplicationTests
 
       manifest = Dir["#{app_path}/public/assets/.sprockets-manifest-*.json"].first
       assets = ActiveSupport::JSON.decode(File.read(manifest))
-      assert asset_path = assets["assets"].find { |(k, _)| k && k =~ /.png/ }[1]
+      assert asset_path = assets["assets"].find { |(k, _)| /.png/.match?(k) }[1]
 
       # Load app env
       app "development"
 
-      get "/assets/#{URI.parser.escape(asset_path)}"
+      get "/assets/#{URI::RFC2396_Parser.new.escape(asset_path)}"
       assert_match "not an image really", last_response.body
       assert_file_exists("#{app_path}/public/assets/#{asset_path}")
     end
@@ -374,7 +347,7 @@ module ApplicationTests
       # Load app env
       app "production"
 
-      get "/assets/demo.js"
+      get("/assets/demo.js", {}, "HTTPS" => "on")
       assert_equal 404, last_response.status
     end
 
@@ -436,7 +409,7 @@ module ApplicationTests
       class ::PostsController < ActionController::Base ; end
 
       # the debug_assets params isn't used if compile is off
-      get "/posts?debug_assets=true"
+      get("/posts?debug_assets=true", {}, "HTTPS" => "on")
       assert_match(/<script src="\/assets\/application-([0-z]+)\.js"><\/script>/, last_response.body)
       assert_no_match(/<script src="\/assets\/xmlhr-([0-z]+)\.js"><\/script>/, last_response.body)
     end
@@ -466,13 +439,13 @@ module ApplicationTests
     end
 
     test "digested assets are not mistakenly removed" do
-      app_file "app/assets/application.js", "alert();"
+      app_file "app/assets/application.css", "div { font-weight: bold }"
       add_to_config "config.assets.compile = true"
 
       precompile!
 
-      files = Dir["#{app_path}/public/assets/application-*.js"]
-      assert_equal 1, files.length, "Expected digested application.js asset to be generated, but none found"
+      files = Dir["#{app_path}/public/assets/application-*.css"]
+      assert_equal 1, files.length, "Expected digested application.css asset to be generated, but none found"
     end
 
     test "digested assets are removed from configured path" do
@@ -487,7 +460,7 @@ module ApplicationTests
       assert_equal 0, files.length, "Expected application.js asset to be removed, but still exists"
     end
 
-    test "asset urls should use the request's protocol by default" do
+    test "asset URLs should use the request's protocol by default" do
       app_with_assets_in_view
       add_to_config "config.asset_host = 'example.com'"
       add_to_env_config "development", "config.assets.digest = false"
@@ -498,20 +471,12 @@ module ApplicationTests
       class ::PostsController < ActionController::Base; end
 
       get "/posts", {}, { "HTTPS" => "off" }
-      if sprockets_4?
-        assert_match('src="http://example.com/assets/application.debug.js', last_response.body)
-      else
-        assert_match('src="http://example.com/assets/application.self.js', last_response.body)
-      end
+      assert_match('src="http://example.com/assets/application.js', last_response.body)
       get "/posts", {}, { "HTTPS" => "on" }
-      if sprockets_4?
-        assert_match('src="https://example.com/assets/application.debug.js', last_response.body)
-      else
-        assert_match('src="https://example.com/assets/application.self.js', last_response.body)
-      end
+      assert_match('src="https://example.com/assets/application.js', last_response.body)
     end
 
-    test "asset urls should be protocol-relative if no request is in scope" do
+    test "asset URLs should be protocol-relative if no request is in scope" do
       app_file "app/assets/images/rails.png", "notreallyapng"
       app_file "app/assets/javascripts/image_loader.js.erb", "var src='<%= image_path('rails.png') %>';"
       add_to_config "config.assets.precompile = %w{rails.png image_loader.js}"
@@ -536,16 +501,11 @@ module ApplicationTests
     end
 
     private
-
-      def sprockets_4?
-        Sprockets::VERSION >= "4.0.0"
-      end
-
       def app_with_assets_in_view
         app_file "app/assets/javascripts/application.js", "//= require_tree ."
         app_file "app/assets/javascripts/xmlhr.js", "function f1() { alert(); }"
         app_file "app/views/posts/index.html.erb", "<%= javascript_include_tag 'application' %>"
-        app_file "app/assets/config/manifest.js", <<-JS.strip_heredoc
+        app_file "app/assets/config/manifest.js", <<~JS
           //= link_tree ../images
           //= link_directory ../stylesheets .css
           //= link_directory ../javascripts .js
@@ -555,7 +515,7 @@ module ApplicationTests
         Rails.application.routes.draw do
           get '/posts', :to => "posts#index"
         end
-      RUBY
+        RUBY
       end
   end
 end
